@@ -6,14 +6,19 @@ package ELF::Extract::Sections::Meta::Scanner;
 
 # ABSTRACT: Interface Contract for Scanners
 
-our $VERSION = '1.000000';
+our $VERSION = '1.001000';
 
 our $AUTHORITY = 'cpan:KENTNL'; # AUTHORITY
 
 use Moose::Role qw( with requires );
 with 'MooseX::Log::Log4perl';
 
-requires( 'open_file', 'next_section', 'section_offset', 'section_size', 'section_name', 'can_compute_size' );
+requires 'open_file';
+requires 'next_section';
+requires 'section_offset';
+requires 'section_size';
+requires 'section_name';
+requires 'can_compute_size';
 
 no Moose::Role;
 
@@ -31,34 +36,46 @@ ELF::Extract::Sections::Meta::Scanner - Interface Contract for Scanners
 
 =head1 VERSION
 
-version 1.000000
+version 1.001000
 
 =head1 Required Methods for Applying Roles
 
-=head2 -> open_file file => FILE
+=head2 C<open_file>
+
+  my $file = $scanner->open_file( file => FILE )
 
 Must take a file name and assume a state reset.
 
-=head2 -> next_section
+=head2 C<next_section>
+
+  my $boolean = $scanner->next_section
 
 Must return true if a section was discovered.
 Must return false otherwise.
 This method is called before getting data out.
 
-=head2 -> section_offset
+=head2 C<section_offset>
+
+  my $offset = $scanner->section_offset;
 
 Returns the offset as an Integer
 
-=head2 -> section_size
+=head2 C<section_size>
+
+  my $size = $scanner->section_size;
 
 Returns the sections computed size ( if possible )
 If you can't compute the size, please call $self->log->logcroak()
 
-=head2 -> section_name
+=head2 C<section_name>
+
+  my $name = $scanner->section_name;
 
 Returns the sections name
 
-=head2 -> can_compute_size
+=head2 C<can_compute_size>
+
+  my $boolean = $scanner->can_compute_size;
 
 This returns whether or not this code is capable of discerning section sizes on its own.
 return 1 if true, return C<undef> otherwise.
